modulapp_utils library
Mixins
-
AnimationMixin<
T extends StatefulWidget> -
This mixin simplify the implementation of an animated widget
Use that mixin on a StatefulWidget's state like this:
class MyClassState extends State<MyClass> with SingleTickerProviderStateMixin, Animated<MyClass>
Extensions
- BooleanUtils on bool
- ColorUtils on Color
- ContextUtils on BuildContext
-
It provides some getters to easily access to current screen size
final currentScreenSize = context.screenSize; - DateTimeUtils on DateTime
-
IterableNullableUtils
on Iterable<
T> ? -
IterableUtils
on Iterable<
T> -
ListUtils
on List<
T> -
MapEntryListUtils
on Iterable<
MapEntry< T, V> > -
MapUtils
on Map<
K, V> -
NestedIterableUtils
on Iterable<
Iterable< T> > - NullableStringToDateUtils on String?
- ObjectNullableUtils on Object?
-
PairListUtils
on Iterable<
Pair< T, V> > - RegexUtils on String
- StringToDateUtils on String
- StringUtils on String
- ToListUtils on Object?
-
WidgeStatePropertytUtils
on WidgetStateProperty<
T> ? - WidgetUtils on Widget