StringUtils extension
- on
Properties
- lineLength → int
-
Available on String, provided by the StringUtils extension
Returns number of linesno setter
Methods
-
clean(
) → String -
Available on String, provided by the StringUtils extension
Forces lower case and removes all accented characters -
cleanAndSplit(
) → List< String> -
Available on String, provided by the StringUtils extension
Forces lower case and removes all accents and splits all words -
computeSize(
double fontSize, String fontFamily, {FontWeight? fontWeight, FontStyle? fontStyle}) → Size -
Available on String, provided by the StringUtils extension
Returns rendered text size with small security margins -
getAllAfterFirst(
String target) → String? -
Available on String, provided by the StringUtils extension
Returns text placed after first target -
getAllAfterLast(
String target) → String? -
Available on String, provided by the StringUtils extension
Returns text placed after last target -
getAllBeforeFirst(
String target) → String? -
Available on String, provided by the StringUtils extension
Returns text placed before first target -
getAllBeforeLast(
String target) → String? -
Available on String, provided by the StringUtils extension
Returns text placed before last target -
getAllBetween(
String target1, String target2) → String? -
Available on String, provided by the StringUtils extension
Returns text placed between targets -
limit(
[int maxLength = 100]) → String -
Available on String, provided by the StringUtils extension
Limits String's length by adding ... -
parseAsDouble(
) → double? -
Available on String, provided by the StringUtils extension
Tries to parse String as double -
removeDiacritics(
) → String -
Available on String, provided by the StringUtils extension
Removes all accented characters -
removeLastCharacter(
) → String -
Available on String, provided by the StringUtils extension
Removes last character -
removeLastZeros(
) → String -
Available on String, provided by the StringUtils extension
Cleans up decimals -
searchWords(
List< String> searchedWords) → List<String> -
Available on String, provided by the StringUtils extension
Search for words ignoring case and accents -
splitWords(
) → List< String> -
Available on String, provided by the StringUtils extension
Splits all words separated by non alphabetic characters